==> iChip_1.0.0.zip: iChip/doc/iChip.R <==
###################################################
### chunk number 1: 
###################################################
library(iChip)
data(oct4)
head(oct4,n=3L)


###################################################
### chunk number 2: 
###################################################
oct4 = oct4[order(oct4[,1],oct4[,2]),]


###################################################
### chunk number 3: 
###################################################
oct4lmt = lmtstat(oct4[,5:6],oct4[,3:4])


###################################################
### chunk number 4: 
###################################################
oct4Y = cbind(oct4[,1],oct4lmt)


###################################################
### chunk number 5: 
###################################################
set.seed(777)
oct4res2 = iChip2(Y=oct4Y,burnin=2000,sampling=10000,winsize=2,sdcut=2,beta=1.25,verbose=FALSE)


###################################################
### chunk number 6: 
###################################################
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(oct4res2$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(oct4res2$lambda0, pch=".", xlab="Iterations", ylab="lambda0")
plot(oct4res2$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(oct4res2$lambda1, pch=".", xlab="Iterations", ylab="lambda1")


###################################################
### chunk number 7: 
###################################################
hist(oct4res2$pp)


###################################################
### chunk number 8: 
###################################################
reg1 = enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res2$pp,cutoff=0.9,method="ppcut",maxgap=500)
print(reg1)


###################################################
### chunk number 9: 
###################################################
reg2 = enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res2$pp,cutoff=0.01,method="fdrcut",maxgap=500)
print(reg2)


###################################################
### chunk number 10: 
###################################################
bed1 = data.frame(chr=paste("chr",reg2[,1],sep=""),reg2[,2:3])
print(bed1[1:3,])


###################################################
### chunk number 11: 
###################################################
bed2 = data.frame(chr=paste("chr",reg2[,1],sep=""),gstart=reg2[,6]-100,gend=reg2[,6]+100)
print(bed2[1:3,])


###################################################
### chunk number 12: 
###################################################
oct4res1 =iChip1(enrich=oct4lmt,burnin=2000,sampling=10000,sdcut=2,beta0=3,minbeta=0,maxbeta=100,normsd=0.1,verbose=FALSE)


###################################################
### chunk number 13: 
###################################################
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(oct4res1$beta, pch=".", xlab="Iterations", ylab="beta")
plot(oct4res1$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(oct4res1$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(oct4res1$lambda, pch=".", xlab="Iterations", ylab="lambda")


###################################################
### chunk number 14: 
###################################################
enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res1$pp,cutoff=0.9,method="ppcut",maxgap=500)
enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res1$pp,cutoff=0.01,method="fdrcut",maxgap=500)


###################################################
### chunk number 15: 
###################################################
data(p53)
head(p53,n=3L)
# sort the p53 data by chromosome and genomic position
p53 = p53[order(p53[,1],p53[,2]),]
p53lmt = lmtstat(p53[,9:14],p53[,3:8])
p53Y = cbind(p53[,1],p53lmt)


###################################################
### chunk number 16: 
###################################################
p53res2 = iChip2(Y=p53Y,burnin=2000,sampling=10000,winsize=2,sdcut=2,beta=2.5)


###################################################
### chunk number 17: 
###################################################
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(p53res2$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(p53res2$lambda0, pch=".", xlab="Iterations", ylab="lambda0")
plot(p53res2$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(p53res2$lambda1, pch=".", xlab="Iterations", ylab="lambda1")


###################################################
### chunk number 18: 
###################################################
hist(p53res2$pp)


###################################################
### chunk number 19: 
###################################################
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res2$pp,cutoff=0.9,method="ppcut",maxgap=500)
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res2$pp,cutoff=0.01,method="fdrcut",maxgap=500)


###################################################
### chunk number 20: 
###################################################
p53res1 =iChip1(enrich=p53lmt,burnin=2000,sampling=10000,sdcut=2,beta0=3,minbeta=0,maxbeta=100,normsd=0.1,verbose=FALSE)


###################################################
### chunk number 21: 
###################################################
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(p53res1$beta, pch=".", xlab="Iterations", ylab="beta")
plot(p53res1$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(p53res1$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(p53res1$lambda, pch=".", xlab="Iterations", ylab="lambda")


###################################################
### chunk number 22: 
###################################################
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res1$pp,cutoff=0.9,method="ppcut",maxgap=500)
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res1$pp,cutoff=0.01,method="fdrcut",maxgap=500)


###################################################
### chunk number 23: 
###################################################
randomY = cbind(p53[,1],rnorm(10000,0,1))
randomres2 = iChip2(Y=randomY,burnin=2000,sampling=10000,winsize=2,sdcut=2,beta=2.5,verbose=FALSE)
table(randomres2$pp)


###################################################
### chunk number 24: 
###################################################
randomres1 =iChip1(enrich=randomY[,2],burnin=2000,sampling=10000,sdcut=2,beta0=3,minbeta=0,maxbeta=100,normsd=0.1,verbose=FALSE)
table(randomres1$pp)


###################################################
### chunk number 25: 
###################################################
sessionInfo()

==> iChip_1.4.0.zip: iChip/doc/iChip.R <==
###################################################
### chunk number 1: 
###################################################
#line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
library(iChip)
data(oct4)
head(oct4,n=3L)


###################################################
### chunk number 2: 
###################################################
#line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
oct4 = oct4[order(oct4[,1],oct4[,2]),]


###################################################
### chunk number 3: 
###################################################
#line 105 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
oct4lmt = lmtstat(oct4[,5:6],oct4[,3:4])


###################################################
### chunk number 4: 
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
oct4Y = cbind(oct4[,1],oct4lmt)


###################################################
### chunk number 5: 
###################################################
#line 131 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
set.seed(777)
oct4res2 = iChip2(Y=oct4Y,burnin=2000,sampling=10000,winsize=2,sdcut=2,beta=1.25,verbose=FALSE)


###################################################
### chunk number 6: 
###################################################
#line 142 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(oct4res2$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(oct4res2$lambda0, pch=".", xlab="Iterations", ylab="lambda0")
plot(oct4res2$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(oct4res2$lambda1, pch=".", xlab="Iterations", ylab="lambda1")


###################################################
### chunk number 7: 
###################################################
#line 155 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
hist(oct4res2$pp)


###################################################
### chunk number 8: 
###################################################
#line 164 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
reg1 = enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res2$pp,cutoff=0.9,method="ppcut",maxgap=500)
print(reg1)


###################################################
### chunk number 9: 
###################################################
#line 172 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
reg2 = enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res2$pp,cutoff=0.01,method="fdrcut",maxgap=500)
print(reg2)


###################################################
### chunk number 10: 
###################################################
#line 181 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
bed1 = data.frame(chr=paste("chr",reg2[,1],sep=""),reg2[,2:3])
print(bed1[1:3,])


###################################################
### chunk number 11: 
###################################################
#line 189 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
bed2 = data.frame(chr=paste("chr",reg2[,1],sep=""),gstart=reg2[,6]-100,gend=reg2[,6]+100)
print(bed2[1:3,])


###################################################
### chunk number 12: 
###################################################
#line 196 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
oct4res1 =iChip1(enrich=oct4lmt,burnin=2000,sampling=10000,sdcut=2,beta0=3,minbeta=0,maxbeta=10,normsd=0.1,verbose=FALSE)


###################################################
### chunk number 13: 
###################################################
#line 203 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(oct4res1$beta, pch=".", xlab="Iterations", ylab="beta")
plot(oct4res1$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(oct4res1$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(oct4res1$lambda, pch=".", xlab="Iterations", ylab="lambda")


###################################################
### chunk number 14: 
###################################################
#line 214 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res1$pp,cutoff=0.9,method="ppcut",maxgap=500)
enrichreg(pos=oct4[,1:2],enrich=oct4lmt,pp=oct4res1$pp,cutoff=0.01,method="fdrcut",maxgap=500)


###################################################
### chunk number 15: 
###################################################
#line 223 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
data(p53)
head(p53,n=3L)
# sort the p53 data by chromosome and genomic position
p53 = p53[order(p53[,1],p53[,2]),]
p53lmt = lmtstat(p53[,9:14],p53[,3:8])
p53Y = cbind(p53[,1],p53lmt)


###################################################
### chunk number 16: 
###################################################
#line 236 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
p53res2 = iChip2(Y=p53Y,burnin=2000,sampling=10000,winsize=2,sdcut=2,beta=2.5)


###################################################
### chunk number 17: 
###################################################
#line 241 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(p53res2$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(p53res2$lambda0, pch=".", xlab="Iterations", ylab="lambda0")
plot(p53res2$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(p53res2$lambda1, pch=".", xlab="Iterations", ylab="lambda1")


###################################################
### chunk number 18: 
###################################################
#line 254 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
hist(p53res2$pp)


###################################################
### chunk number 19: 
###################################################
#line 259 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res2$pp,cutoff=0.9,method="ppcut",maxgap=500)
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res2$pp,cutoff=0.01,method="fdrcut",maxgap=500)


###################################################
### chunk number 20: 
###################################################
#line 266 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
p53res1 =iChip1(enrich=p53lmt,burnin=2000,sampling=10000,sdcut=2,beta0=3,minbeta=0,maxbeta=10,normsd=0.1,verbose=FALSE)


###################################################
### chunk number 21: 
###################################################
#line 271 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
par(mfrow=c(2,2), mar=c(4.1, 4.1, 2.0, 1.0))
plot(p53res1$beta, pch=".", xlab="Iterations", ylab="beta")
plot(p53res1$mu0, pch=".", xlab="Iterations", ylab="mu0")
plot(p53res1$mu1, pch=".", xlab="Iterations", ylab="mu1")
plot(p53res1$lambda, pch=".", xlab="Iterations", ylab="lambda")


###################################################
### chunk number 22: 
###################################################
#line 280 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res1$pp,cutoff=0.9,method="ppcut",maxgap=500)
enrichreg(pos=p53[,1:2],enrich=p53lmt,pp=p53res1$pp,cutoff=0.01,method="fdrcut",maxgap=500)


###################################################
### chunk number 23: 
###################################################
#line 288 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
randomY = cbind(p53[,1],rnorm(10000,0,1))
randomres2 = iChip2(Y=randomY,burnin=1000,sampling=5000,winsize=2,sdcut=2,beta=2.5,verbose=FALSE)
table(randomres2$pp)


###################################################
### chunk number 24: 
###################################################
#line 312 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
randomres1 =iChip1(enrich=randomY[,2],burnin=1000,sampling=5000,sdcut=2,beta0=3,minbeta=0,maxbeta=10,normsd=0.1,verbose=FALSE)
table(randomres1$pp)


###################################################
### chunk number 25: 
###################################################
#line 353 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpYNWWpm/R.INSTALL3870284f/iChip/inst/doc/iChip.Rnw"
sessionInfo()
